    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="X-Clacks-Overhead" content="GNU Terry Pratchett">
    <link rel="preload" href="/static/fonts/noto-sans-display-latin-500.woff2" as="font" type="font/woff2" crossorigin>
    <link rel="preload" href="/static/fonts/fira-code-v12-latin-500.woff2" as="font" type="font/woff2" crossorigin>
    <link rel="preload" href="/static/fonts/fira-code-v12-latin-600.woff2" as="font" type="font/woff2" crossorigin>
    <link rel="preload" href="/static/fonts/fira-code-v12-latin-700.woff2" as="font" type="font/woff2" crossorigin>
    <link rel="preload" href="/static/fonts/noto-sans-display-latin-500italic.woff2" as="font" type="font/woff2"
        crossorigin>
    <link rel="stylesheet" href="/static/main.css">
    <link rel="icon" type="image/x-icon" href="/favicon.ico">
